@@ -37,7 +37,7 @@
 
 from os.path import basename
 import github.GithubObject
-import github.GitAuthor
+import github.NamedUser
 import github.GitReleaseAsset
 
 
@@ -108,7 +108,7 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
     @property
     def author(self):
         """
-        :type: :class:`github.GitAuthor.GitAuthor`
+        :type: :class:`github.NamedUser.NamedUser`
         """
         self._completeIfNotSet(self._author)
         return self._author.value
@@ -285,7 +285,7 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
         if "prerelease" in attributes:
             self._prerelease = self._makeBoolAttribute(attributes["prerelease"])
         if "author" in attributes:
-            self._author = self._makeClassAttribute(github.GitAuthor.GitAuthor, attributes["author"])
+            self._author = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["author"])
         if "url" in attributes:
             self._url = self._makeStringAttribute(attributes["url"])
         if "upload_url" in attributes:
