@@ -1,11 +1,14 @@
 # -*- coding: utf-8 -*-
 
-# ########################## Copyrights and license ############################
+############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2017 Jannis Gebauer <ja.geb@me.com>                                #
+# Copyright 2017 Simon <spam@esemi.ru>                                         #
+# Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
+# Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
-# http://pygithub.github.io/PyGithub/v1/index.html                             #
+# http://pygithub.readthedocs.io/                                              #
 #                                                                              #
 # PyGithub is free software: you can redistribute it and/or modify it under    #
 # the terms of the GNU Lesser General Public License as published by the Free  #
@@ -20,7 +23,7 @@
 # You should have received a copy of the GNU Lesser General Public License     #
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
-# ##############################################################################
+################################################################################
 
 import github.GithubObject
 import github.PaginatedList
@@ -36,12 +39,14 @@ import github.Event
 import github.Authorization
 import github.Notification
 
-INTEGRATION_PREVIEW_HEADERS = {"Accept": "application/vnd.github.machine-man-preview+json"}
+from . import Consts
+
+INTEGRATION_PREVIEW_HEADERS = {"Accept": Consts.mediaTypeIntegrationPreview}
 
 
 class Installation(github.GithubObject.NonCompletableGithubObject):
     """
-    This class represents Installations as in https://developer.github.com/v3/integrations/installations
+    This class represents Installations. The reference can be found here https://developer.github.com/v3/apps/installations/
     """
 
     def __repr__(self):
@@ -72,4 +77,4 @@ class Installation(github.GithubObject.NonCompletableGithubObject):
 
     def _useAttributes(self, attributes):
         if "id" in attributes:  # pragma no branch
-            self._id = self._makeIntAttribute(attributes["id"])
\ No newline at end of file
+            self._id = self._makeIntAttribute(attributes["id"])
